from pathlib import Path
from typing import ClassVar

from pydantic_settings import BaseSettings, SettingsConfigDict


class Settings(BaseSettings):
    model_config = SettingsConfigDict(env_file=".env", case_sensitive=True)

    # Base settings
    PROJECT_NAME: str = "Multimodal Ticketing System"
    PROJECT_DESCRIPTION: str = "A system for purchasing tickets for various transportation modes"
    VERSION: str = "0.1.0"
    API_V1_STR: str = "/api/v1"

    # Security settings
    SECRET_KEY: str = "09d25e094faa6ca2556c818166b7a9563b93f7099f6f0f4caa6cf63b88e8d3e7"  # CHANGE IN PRODUCTION!
    ALGORITHM: str = "HS256"
    ACCESS_TOKEN_EXPIRE_MINUTES: int = 30

    # Database settings
    DB_DIR: ClassVar[Path] = Path("/app") / "storage" / "db"
    SQLALCHEMY_DATABASE_URL: str = f"sqlite:///{DB_DIR}/db.sqlite"


settings = Settings()

# Ensure database directory exists
settings.DB_DIR.mkdir(parents=True, exist_ok=True)